AnnotationEventsPage class

Constructors

AnnotationEventsPage({required String channel, required String messageSerial, required int limit, required bool hasMore, required String? nextCursor, required List<Map<Object?, Object?>> items, Future<AnnotationEventsPage> fetchNext(String cursor)?})

Properties

channel String
final
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
final
items List<Map<Object?, Object?>>
final
limit int
final
messageSerial String
final
nextCursor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasNext() bool
next() Future<AnnotationEventsPage>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited