DeltaStats class

Constructors

DeltaStats({required int totalMessages, required int deltaMessages, required int fullMessages, required int totalBytesWithoutCompression, required int totalBytesWithCompression, required int bandwidthSaved, required double bandwidthSavedPercent, required int errors, required int channelCount, required List<ChannelDeltaStats> channels})
const

Properties

bandwidthSaved int
final
bandwidthSavedPercent double
final
channelCount int
final
channels List<ChannelDeltaStats>
final
deltaMessages int
final
errors int
final
fullMessages int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBytesWithCompression int
final
totalBytesWithoutCompression int
final
totalMessages int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited