FilterNode class

Constructors

FilterNode({String? op, String? key, String? cmp, String? val, List<String>? vals, List<FilterNode>? nodes})
const

Properties

cmp String?
final
hashCode int
The hash code for this object.
no setterinherited
key String?
final
nodes List<FilterNode>?
final
op String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
val String?
final
vals List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited