UserFacade class

Constructors

UserFacade()

Properties

hashCode int
The hash code for this object.
no setterinherited
isSignInRequested bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userData Map<Object?, Object?>?
getter/setter pair
userId String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String eventName, EventCallback callback) → EventBindingToken
signIn() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited