MessageExtras class
Constructors
Properties
-
ai
→ Map<
String, Object?> ? -
no setter
- echo → bool?
-
final
- ephemeral → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, Object> ? -
final
- idempotencyKey → String?
-
final
-
raw
→ Map<
String, Object?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String key) → Object?