UserAuthenticationOptions class
Constructors
-
UserAuthenticationOptions({String endpoint = '/sockudo/user-auth', Map<
String, String> headers = const <String, String>{}, Map<String, AuthValue> params = const <String, AuthValue>{}, Map<String, String> headersProvider()?, Map<String, AuthValue> paramsProvider()?, UserAuthenticationHandler? customHandler}) -
const
Properties
- customHandler → UserAuthenticationHandler?
-
final
- endpoint → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
-
headersProvider
→ Map<
String, String> Function()? -
final
-
params
→ Map<
String, AuthValue> -
final
-
paramsProvider
→ Map<
String, AuthValue> Function()? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited